==> jc-1.4.0.tar.gz: javax/swing/JComponent__24ActionListenerProxy.h <==
// class javax.swing.JComponent$ActionListenerProxy

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class 62a531c0c35c7719 javax_swing_JComponent__24ActionListenerProxy

// header file dependencies
// @dep_header javax_swing_AbstractAction

#include "javax/swing/AbstractAction.h"

#ifndef _JC_javax_swing_JComponent__24ActionListenerProxy_H_
#define _JC_javax_swing_JComponent__24ActionListenerProxy_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_awt_event_ActionListener$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_JComponent__24ActionListenerProxy$sub_refs	_jc_javax_swing_JComponent__24ActionListenerProxy$sub_refs;
typedef struct _jc_javax_swing_JComponent__24ActionListenerProxy$sub_nonrefs	_jc_javax_swing_JComponent__24ActionListenerProxy$sub_nonrefs;
typedef struct _jc_javax_swing_JComponent__24ActionListenerProxy$refs	_jc_javax_swing_JComponent__24ActionListenerProxy$refs;
typedef struct _jc_javax_swing_JComponent__24ActionListenerProxy$nonrefs	_jc_javax_swing_JComponent__24ActionListenerProxy$nonrefs;
typedef struct _jc_javax_swing_JComponent__24ActionListenerProxy$object	_jc_javax_swing_JComponent__24ActionListenerProxy$object;

typedef const struct _jc_javax_swing_JComponent__24ActionListenerProxy$vmethods	_jc_javax_swing_JComponent__24ActionListenerProxy$vmethods;
typedef const struct _jc_javax_swing_JComponent__24ActionListenerProxy$vtable	_jc_javax_swing_JComponent__24ActionListenerProxy$vtable;
typedef const struct _jc_javax_swing_JComponent__24ActionListenerProxy$vtype	_jc_javax_swing_JComponent__24ActionListenerProxy$vtype;

// Constructors
extern void _jc_javax_swing_JComponent__24ActionListenerProxy$method$_init$45f811248a1af87a(_jc_env *, struct _jc_javax_swing_JComponent__24ActionListenerProxy$object *, struct _jc_object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_javax_swing_JComponent__24ActionListenerProxy$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_JComponent__24ActionListenerProxy$object *, struct _jc_java_awt_event_ActionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JComponent__24ActionListenerProxy$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_JComponent__24ActionListenerProxy$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_JComponent__24ActionListenerProxy$object *, struct _jc_java_awt_event_ActionEvent$object *);
};

// Vtable
struct _jc_javax_swing_JComponent__24ActionListenerProxy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_JComponent__24ActionListenerProxy$vmethods	javax_swing_JComponent__24ActionListenerProxy;
};

// Vtype
struct _jc_javax_swing_JComponent__24ActionListenerProxy$vtype {
	_jc_type			type;
	_jc_javax_swing_JComponent__24ActionListenerProxy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JComponent__24ActionListenerProxy$sub_refs {
	struct _jc_object	*target;
	struct _jc_java_lang_String$object	*bindingCommandName;
};

// Reference instance fields (object)
struct _jc_javax_swing_JComponent__24ActionListenerProxy$refs {
    _jc_javax_swing_JComponent__24ActionListenerProxy$sub_refs	javax_swing_JComponent__24ActionListenerProxy;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JComponent__24ActionListenerProxy$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JComponent__24ActionListenerProxy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_JComponent__24ActionListenerProxy$sub_nonrefs	javax_swing_JComponent__24ActionListenerProxy;
};

// Object instance structure
struct _jc_javax_swing_JComponent__24ActionListenerProxy$object {
	_jc_javax_swing_JComponent__24ActionListenerProxy$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JComponent__24ActionListenerProxy$vtype	*vtype;
	_jc_javax_swing_JComponent__24ActionListenerProxy$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JComponent__24ActionListenerProxy$vtype _jc_javax_swing_JComponent__24ActionListenerProxy$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JComponent__24ActionListenerProxy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JComponent__24ActionListenerProxy$class_object;

#endif	/* _JC_javax_swing_JComponent__24ActionListenerProxy_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JComponent__24ActionListenerProxy.h <==
// class javax.swing.JComponent$ActionListenerProxy

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class 62a531c0c35c7719 javax_swing_JComponent__24ActionListenerProxy

// header file dependencies
// @dep_header javax_swing_AbstractAction

#include "javax/swing/AbstractAction.h"

#ifndef _JC_javax_swing_JComponent__24ActionListenerProxy_H_
#define _JC_javax_swing_JComponent__24ActionListenerProxy_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_awt_event_ActionListener$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_JComponent__24ActionListenerProxy$sub_refs	_jc_javax_swing_JComponent__24ActionListenerProxy$sub_refs;
typedef struct _jc_javax_swing_JComponent__24ActionListenerProxy$sub_nonrefs	_jc_javax_swing_JComponent__24ActionListenerProxy$sub_nonrefs;
typedef struct _jc_javax_swing_JComponent__24ActionListenerProxy$refs	_jc_javax_swing_JComponent__24ActionListenerProxy$refs;
typedef struct _jc_javax_swing_JComponent__24ActionListenerProxy$nonrefs	_jc_javax_swing_JComponent__24ActionListenerProxy$nonrefs;
typedef struct _jc_javax_swing_JComponent__24ActionListenerProxy$object	_jc_javax_swing_JComponent__24ActionListenerProxy$object;

typedef const struct _jc_javax_swing_JComponent__24ActionListenerProxy$vmethods	_jc_javax_swing_JComponent__24ActionListenerProxy$vmethods;
typedef const struct _jc_javax_swing_JComponent__24ActionListenerProxy$vtable	_jc_javax_swing_JComponent__24ActionListenerProxy$vtable;
typedef const struct _jc_javax_swing_JComponent__24ActionListenerProxy$vtype	_jc_javax_swing_JComponent__24ActionListenerProxy$vtype;

// Constructors
extern void _jc_javax_swing_JComponent__24ActionListenerProxy$method$_init$45f811248a1af87a(_jc_env *, struct _jc_javax_swing_JComponent__24ActionListenerProxy$object *, struct _jc_object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_JComponent__24ActionListenerProxy$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_JComponent__24ActionListenerProxy$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JComponent__24ActionListenerProxy$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_JComponent__24ActionListenerProxy$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_JComponent__24ActionListenerProxy$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JComponent__24ActionListenerProxy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_JComponent__24ActionListenerProxy$vmethods	javax_swing_JComponent__24ActionListenerProxy;
};

// Vtype
struct _jc_javax_swing_JComponent__24ActionListenerProxy$vtype {
	_jc_type			type;
	_jc_javax_swing_JComponent__24ActionListenerProxy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JComponent__24ActionListenerProxy$sub_refs {
	struct _jc_object	*target;
	struct _jc_java_lang_String$object	*bindingCommandName;
};

// Reference instance fields (object)
struct _jc_javax_swing_JComponent__24ActionListenerProxy$refs {
    _jc_javax_swing_JComponent__24ActionListenerProxy$sub_refs	javax_swing_JComponent__24ActionListenerProxy;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JComponent__24ActionListenerProxy$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JComponent__24ActionListenerProxy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_JComponent__24ActionListenerProxy$sub_nonrefs	javax_swing_JComponent__24ActionListenerProxy;
};

// Object instance structure
struct _jc_javax_swing_JComponent__24ActionListenerProxy$object {
	_jc_javax_swing_JComponent__24ActionListenerProxy$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JComponent__24ActionListenerProxy$vtype	*vtype;
	_jc_javax_swing_JComponent__24ActionListenerProxy$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JComponent__24ActionListenerProxy$vtype _jc_javax_swing_JComponent__24ActionListenerProxy$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JComponent__24ActionListenerProxy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JComponent__24ActionListenerProxy$class_object;

#endif	/* _JC_javax_swing_JComponent__24ActionListenerProxy_H_ */
